==> gretl_1.4.1.orig.tar.gz: gretl-1.4.1/lib/src/texprint.h <==
/* gretl - The Gnu Regression, Econometrics and Time-series Library
 * Copyright (C) 1999-2000 Ramu Ramanathan and Allin Cottrell
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this software; if not, write to the 
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/* texprint.h for gretl */

/* functions follow */

int tex_print_equation (const MODEL *pmod, const DATAINFO *pdinfo, 
			const int standalone, PRN *prn);

int tex_print_model (MODEL *pmod, const DATAINFO *pdinfo, PRN *prn);

int tex_print_coeff (const DATAINFO *pdinfo, const MODEL *pmod, 
		     int i, PRN *prn);

int texprint (MODEL *pmod, const DATAINFO *pdinfo,
	      char *texfile, gretlopt opt);

char *tex_escape (char *targ, const char *src);

void tex_dcolumn_double (double xx, char *numstr);

void set_gretl_tex_preamble (void);

void gretl_tex_preamble (PRN *prn, int ams);

void tex_print_obs_marker (int t, const DATAINFO *pdinfo, PRN *prn);

==> gretl_1.5.0.orig.tar.gz: gretl-1.5.0/lib/src/texprint.h <==
/* gretl - The Gnu Regression, Econometrics and Time-series Library
 * Copyright (C) 1999-2000 Ramu Ramanathan and Allin Cottrell
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License 
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License 
 * along with this software; if not, write to the 
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/* texprint.h for gretl */

/* functions follow */

int tex_print_equation (const MODEL *pmod, const DATAINFO *pdinfo, 
			const int standalone, PRN *prn);

int tex_print_model (MODEL *pmod, const DATAINFO *pdinfo, PRN *prn);

int tex_print_coeff (const DATAINFO *pdinfo, const MODEL *pmod, 
		     int i, PRN *prn);

void tex_print_VECM_omega (GRETL_VAR *vecm, const DATAINFO *pdinfo, PRN *prn);

void tex_print_VECM_coint_eqns (GRETL_VAR *vecm, const DATAINFO *pdinfo, PRN *prn);

void tex_print_VAR_ll_stats (GRETL_VAR *var, PRN *prn);

int texprint (MODEL *pmod, const DATAINFO *pdinfo,
	      char *texfile, gretlopt opt);

char *tex_escape (char *targ, const char *src);

void tex_dcolumn_double (double xx, char *numstr);

void set_gretl_tex_preamble (void);

void gretl_tex_preamble (PRN *prn, int ams);

void tex_print_obs_marker (int t, const DATAINFO *pdinfo, PRN *prn);
